# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mobile_platform_reachy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cmobile_platform_reachy.proto\x12\x13reachy.sdk.mobility\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8d\x01\n\x0f\x44irectionVector\x12&\n\x01x\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12&\n\x01y\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x05theta\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"Q\n\x16TargetDirectionCommand\x12\x37\n\tdirection\x18\x01 \x01(\x0b\x32$.reachy.sdk.mobility.DirectionVector\"\x97\x01\n\nGoToVector\x12+\n\x06x_goal\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12+\n\x06y_goal\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12/\n\ntheta_goal\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xc5\x01\n\x0eSetSpeedVector\x12*\n\x05x_vel\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x05y_vel\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12,\n\x07rot_vel\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\x8c\x01\n\x0eOdometryVector\x12&\n\x01x\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12&\n\x01y\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x05theta\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xd3\x01\n\x14\x44istanceToGoalVector\x12,\n\x07\x64\x65lta_x\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12,\n\x07\x64\x65lta_y\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0b\x64\x65lta_theta\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\x08\x64istance\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"P\n\x12\x43ontrolModeCommand\x12:\n\x04mode\x18\x01 \x01(\x0e\x32,.reachy.sdk.mobility.ControlModePossiblities\"J\n\x0fZuuuModeCommand\x12\x37\n\x04mode\x18\x01 \x01(\x0e\x32).reachy.sdk.mobility.ZuuuModePossiblities\":\n\x0c\x42\x61tteryLevel\x12*\n\x05level\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"v\n\x12MobileBasePresence\x12,\n\x08presence\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rmodel_version\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"E\n\x14SetZuuuSafetyRequest\x12-\n\tsafety_on\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"A\n\x12MobilityServiceAck\x12+\n\x07success\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue*H\n\x17\x43ontrolModePossiblities\x12\x15\n\x11NONE_CONTROL_MODE\x10\x00\x12\r\n\tOPEN_LOOP\x10\x01\x12\x07\n\x03PID\x10\x02*{\n\x14ZuuuModePossiblities\x12\x12\n\x0eNONE_ZUUU_MODE\x10\x00\x12\x0b\n\x07\x43MD_VEL\x10\x01\x12\t\n\x05\x42RAKE\x10\x02\x12\x0e\n\nFREE_WHEEL\x10\x03\x12\t\n\x05SPEED\x10\x04\x12\x08\n\x04GOTO\x10\x05\x12\x12\n\x0e\x45MERGENCY_STOP\x10\x06\x32\xb4\x08\n\x0fMobilityService\x12\x65\n\rSendDirection\x12+.reachy.sdk.mobility.TargetDirectionCommand\x1a\'.reachy.sdk.mobility.MobilityServiceAck\x12\\\n\x0cSendSetSpeed\x12#.reachy.sdk.mobility.SetSpeedVector\x1a\'.reachy.sdk.mobility.MobilityServiceAck\x12T\n\x08SendGoTo\x12\x1f.reachy.sdk.mobility.GoToVector\x1a\'.reachy.sdk.mobility.MobilityServiceAck\x12S\n\x0e\x44istanceToGoal\x12\x16.google.protobuf.Empty\x1a).reachy.sdk.mobility.DistanceToGoalVector\x12\x62\n\x0eSetControlMode\x12\'.reachy.sdk.mobility.ControlModeCommand\x1a\'.reachy.sdk.mobility.MobilityServiceAck\x12Q\n\x0eGetControlMode\x12\x16.google.protobuf.Empty\x1a\'.reachy.sdk.mobility.ControlModeCommand\x12\\\n\x0bSetZuuuMode\x12$.reachy.sdk.mobility.ZuuuModeCommand\x1a\'.reachy.sdk.mobility.MobilityServiceAck\x12K\n\x0bGetZuuuMode\x12\x16.google.protobuf.Empty\x1a$.reachy.sdk.mobility.ZuuuModeCommand\x12L\n\x0fGetBatteryLevel\x12\x16.google.protobuf.Empty\x1a!.reachy.sdk.mobility.BatteryLevel\x12J\n\x0bGetOdometry\x12\x16.google.protobuf.Empty\x1a#.reachy.sdk.mobility.OdometryVector\x12P\n\rResetOdometry\x12\x16.google.protobuf.Empty\x1a\'.reachy.sdk.mobility.MobilityServiceAck\x12\x63\n\rSetZuuuSafety\x12).reachy.sdk.mobility.SetZuuuSafetyRequest\x1a\'.reachy.sdk.mobility.MobilityServiceAck2u\n\x19MobileBasePresenceService\x12X\n\x15GetMobileBasePresence\x12\x16.google.protobuf.Empty\x1a\'.reachy.sdk.mobility.MobileBasePresenceb\x06proto3')

_CONTROLMODEPOSSIBLITIES = DESCRIPTOR.enum_types_by_name['ControlModePossiblities']
ControlModePossiblities = enum_type_wrapper.EnumTypeWrapper(_CONTROLMODEPOSSIBLITIES)
_ZUUUMODEPOSSIBLITIES = DESCRIPTOR.enum_types_by_name['ZuuuModePossiblities']
ZuuuModePossiblities = enum_type_wrapper.EnumTypeWrapper(_ZUUUMODEPOSSIBLITIES)
NONE_CONTROL_MODE = 0
OPEN_LOOP = 1
PID = 2
NONE_ZUUU_MODE = 0
CMD_VEL = 1
BRAKE = 2
FREE_WHEEL = 3
SPEED = 4
GOTO = 5
EMERGENCY_STOP = 6


_DIRECTIONVECTOR = DESCRIPTOR.message_types_by_name['DirectionVector']
_TARGETDIRECTIONCOMMAND = DESCRIPTOR.message_types_by_name['TargetDirectionCommand']
_GOTOVECTOR = DESCRIPTOR.message_types_by_name['GoToVector']
_SETSPEEDVECTOR = DESCRIPTOR.message_types_by_name['SetSpeedVector']
_ODOMETRYVECTOR = DESCRIPTOR.message_types_by_name['OdometryVector']
_DISTANCETOGOALVECTOR = DESCRIPTOR.message_types_by_name['DistanceToGoalVector']
_CONTROLMODECOMMAND = DESCRIPTOR.message_types_by_name['ControlModeCommand']
_ZUUUMODECOMMAND = DESCRIPTOR.message_types_by_name['ZuuuModeCommand']
_BATTERYLEVEL = DESCRIPTOR.message_types_by_name['BatteryLevel']
_MOBILEBASEPRESENCE = DESCRIPTOR.message_types_by_name['MobileBasePresence']
_SETZUUUSAFETYREQUEST = DESCRIPTOR.message_types_by_name['SetZuuuSafetyRequest']
_MOBILITYSERVICEACK = DESCRIPTOR.message_types_by_name['MobilityServiceAck']
DirectionVector = _reflection.GeneratedProtocolMessageType('DirectionVector', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTIONVECTOR,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.DirectionVector)
  })
_sym_db.RegisterMessage(DirectionVector)

TargetDirectionCommand = _reflection.GeneratedProtocolMessageType('TargetDirectionCommand', (_message.Message,), {
  'DESCRIPTOR' : _TARGETDIRECTIONCOMMAND,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.TargetDirectionCommand)
  })
_sym_db.RegisterMessage(TargetDirectionCommand)

GoToVector = _reflection.GeneratedProtocolMessageType('GoToVector', (_message.Message,), {
  'DESCRIPTOR' : _GOTOVECTOR,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.GoToVector)
  })
_sym_db.RegisterMessage(GoToVector)

SetSpeedVector = _reflection.GeneratedProtocolMessageType('SetSpeedVector', (_message.Message,), {
  'DESCRIPTOR' : _SETSPEEDVECTOR,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.SetSpeedVector)
  })
_sym_db.RegisterMessage(SetSpeedVector)

OdometryVector = _reflection.GeneratedProtocolMessageType('OdometryVector', (_message.Message,), {
  'DESCRIPTOR' : _ODOMETRYVECTOR,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.OdometryVector)
  })
_sym_db.RegisterMessage(OdometryVector)

DistanceToGoalVector = _reflection.GeneratedProtocolMessageType('DistanceToGoalVector', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCETOGOALVECTOR,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.DistanceToGoalVector)
  })
_sym_db.RegisterMessage(DistanceToGoalVector)

ControlModeCommand = _reflection.GeneratedProtocolMessageType('ControlModeCommand', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLMODECOMMAND,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.ControlModeCommand)
  })
_sym_db.RegisterMessage(ControlModeCommand)

ZuuuModeCommand = _reflection.GeneratedProtocolMessageType('ZuuuModeCommand', (_message.Message,), {
  'DESCRIPTOR' : _ZUUUMODECOMMAND,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.ZuuuModeCommand)
  })
_sym_db.RegisterMessage(ZuuuModeCommand)

BatteryLevel = _reflection.GeneratedProtocolMessageType('BatteryLevel', (_message.Message,), {
  'DESCRIPTOR' : _BATTERYLEVEL,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.BatteryLevel)
  })
_sym_db.RegisterMessage(BatteryLevel)

MobileBasePresence = _reflection.GeneratedProtocolMessageType('MobileBasePresence', (_message.Message,), {
  'DESCRIPTOR' : _MOBILEBASEPRESENCE,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.MobileBasePresence)
  })
_sym_db.RegisterMessage(MobileBasePresence)

SetZuuuSafetyRequest = _reflection.GeneratedProtocolMessageType('SetZuuuSafetyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETZUUUSAFETYREQUEST,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.SetZuuuSafetyRequest)
  })
_sym_db.RegisterMessage(SetZuuuSafetyRequest)

MobilityServiceAck = _reflection.GeneratedProtocolMessageType('MobilityServiceAck', (_message.Message,), {
  'DESCRIPTOR' : _MOBILITYSERVICEACK,
  '__module__' : 'mobile_platform_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.MobilityServiceAck)
  })
_sym_db.RegisterMessage(MobilityServiceAck)

_MOBILITYSERVICE = DESCRIPTOR.services_by_name['MobilityService']
_MOBILEBASEPRESENCESERVICE = DESCRIPTOR.services_by_name['MobileBasePresenceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTROLMODEPOSSIBLITIES._serialized_start=1528
  _CONTROLMODEPOSSIBLITIES._serialized_end=1600
  _ZUUUMODEPOSSIBLITIES._serialized_start=1602
  _ZUUUMODEPOSSIBLITIES._serialized_end=1725
  _DIRECTIONVECTOR._serialized_start=115
  _DIRECTIONVECTOR._serialized_end=256
  _TARGETDIRECTIONCOMMAND._serialized_start=258
  _TARGETDIRECTIONCOMMAND._serialized_end=339
  _GOTOVECTOR._serialized_start=342
  _GOTOVECTOR._serialized_end=493
  _SETSPEEDVECTOR._serialized_start=496
  _SETSPEEDVECTOR._serialized_end=693
  _ODOMETRYVECTOR._serialized_start=696
  _ODOMETRYVECTOR._serialized_end=836
  _DISTANCETOGOALVECTOR._serialized_start=839
  _DISTANCETOGOALVECTOR._serialized_end=1050
  _CONTROLMODECOMMAND._serialized_start=1052
  _CONTROLMODECOMMAND._serialized_end=1132
  _ZUUUMODECOMMAND._serialized_start=1134
  _ZUUUMODECOMMAND._serialized_end=1208
  _BATTERYLEVEL._serialized_start=1210
  _BATTERYLEVEL._serialized_end=1268
  _MOBILEBASEPRESENCE._serialized_start=1270
  _MOBILEBASEPRESENCE._serialized_end=1388
  _SETZUUUSAFETYREQUEST._serialized_start=1390
  _SETZUUUSAFETYREQUEST._serialized_end=1459
  _MOBILITYSERVICEACK._serialized_start=1461
  _MOBILITYSERVICEACK._serialized_end=1526
  _MOBILITYSERVICE._serialized_start=1728
  _MOBILITYSERVICE._serialized_end=2804
  _MOBILEBASEPRESENCESERVICE._serialized_start=2806
  _MOBILEBASEPRESENCESERVICE._serialized_end=2923
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import fan_pb2 as fan__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FanControllerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAllFansId = channel.unary_unary(
                '/reachy.sdk.fan.FanControllerService/GetAllFansId',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=fan__pb2.FansId.FromString,
                )
        self.GetFansState = channel.unary_unary(
                '/reachy.sdk.fan.FanControllerService/GetFansState',
                request_serializer=fan__pb2.FansStateRequest.SerializeToString,
                response_deserializer=fan__pb2.FansState.FromString,
                )
        self.SendFansCommands = channel.unary_unary(
                '/reachy.sdk.fan.FanControllerService/SendFansCommands',
                request_serializer=fan__pb2.FansCommand.SerializeToString,
                response_deserializer=fan__pb2.FansCommandAck.FromString,
                )


class FanControllerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAllFansId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFansState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFansCommands(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FanControllerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAllFansId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllFansId,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=fan__pb2.FansId.SerializeToString,
            ),
            'GetFansState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFansState,
                    request_deserializer=fan__pb2.FansStateRequest.FromString,
                    response_serializer=fan__pb2.FansState.SerializeToString,
            ),
            'SendFansCommands': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFansCommands,
                    request_deserializer=fan__pb2.FansCommand.FromString,
                    response_serializer=fan__pb2.FansCommandAck.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.fan.FanControllerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FanControllerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAllFansId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.fan.FanControllerService/GetAllFansId',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            fan__pb2.FansId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFansState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.fan.FanControllerService/GetFansState',
            fan__pb2.FansStateRequest.SerializeToString,
            fan__pb2.FansState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFansCommands(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.fan.FanControllerService/SendFansCommands',
            fan__pb2.FansCommand.SerializeToString,
            fan__pb2.FansCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
